OH_ImageProcessing_Destroy

Function OH_ImageProcessing_Destroy 

pub unsafe extern "C" fn OH_ImageProcessing_Destroy(
    imageProcessor: *mut OH_ImageProcessing,
) -> ImageProcessing_ErrorCode
Available on crate features api-13 and image-processing only.
Destroy the image processing instance.

Arguments

  • imageProcessor - An image processing instance pointer. It is recommended setting the instance pointer to null after the instance is destroyed.

Returns

  • [IMAGE_PROCESSING_SUCCESS] if the instance is destroyed successfully.

[IMAGE_PROCESSING_ERROR_INVALID_INSTANCE] if instance is null or not an image processing instance.

Available since API-level: 13