OH_ImageProcessing_SetParameter

Function OH_ImageProcessing_SetParameter 

pub unsafe extern "C" fn OH_ImageProcessing_SetParameter(
    imageProcessor: *mut OH_ImageProcessing,
    parameter: *const OH_AVFormat,
) -> ImageProcessing_ErrorCode
Available on crate features api-13 and image-processing only.
Set parameter for image processing.

Add parameter identified by the specified parameter key.

Arguments

  • imageProcessor - An image processing instance pointer.

  • parameter - The parameter for image processing.

Returns

  • [IMAGE_PROCESSING_SUCCESS] if setting parameter is successful.

[IMAGE_PROCESSING_ERROR_INVALID_INSTANCE] if instance is null or not an image processing instance.

[IMAGE_PROCESSING_ERROR_INVALID_PARAMETER] if the parameter is null.

[IMAGE_PROCESSING_ERROR_INVALID_VALUE] if some property of the parameter is invalid. For example, the parameter contains unsupported parameter key or value.

[IMAGE_PROCESSING_ERROR_NO_MEMORY] if memory allocation failed.

Available since API-level: 13