OH_VideoProcessing_Create

Function OH_VideoProcessing_Create 

pub unsafe extern "C" fn OH_VideoProcessing_Create(
    videoProcessor: *mut *mut OH_VideoProcessing,
    type_: c_int,
) -> VideoProcessing_ErrorCode
Available on crate features api-12 and video-processing only.
Create a video processing instance.

Arguments

  • videoProcessor - Output parameter. The *videoProcessor points to a new video processing object. The *videoProcessor must be null before passed in.

  • type - Use VIDEO_PROCESSING_TYPE_XXX to specify the processing type. The processing type of the instance can not be changed.

Returns

  • [VIDEO_PROCESSING_SUCCESS] if creating a video processing instance successfully.

[VIDEO_PROCESSING_ERROR_UNSUPPORTED_PROCESSING] if the type is not supported. For example, if metadata generation is not supported by vendor, it returns unsupported processing.

[VIDEO_PROCESSING_ERROR_CREATE_FAILED] if failed to create a video processing instance.

[VIDEO_PROCESSING_ERROR_INVALID_INSTANCE] if instance is null or *instance is not null.

[VIDEO_PROCESSING_ERROR_INVALID_PARAMETER] if type is invalid.

Available since API-level: 12