OH_VideoProcessing_GetSurface

Function OH_VideoProcessing_GetSurface 

pub unsafe extern "C" fn OH_VideoProcessing_GetSurface(
    videoProcessor: *mut OH_VideoProcessing,
    window: *mut *mut OHNativeWindow,
) -> VideoProcessing_ErrorCode
Available on crate features api-12 and video-processing only.
Create an input surface.

Create the input surface before starting video processing. Call [OH_NativeWindow_DestroyNativeWindow] to destroy the input surface.

Arguments

  • videoProcessor - A video processing instance pointer.

  • window - The input surface pointer. For example, it is the output surface of a video decoder.

Returns

  • [VIDEO_PROCESSING_SUCCESS] if operation is successful.

[VIDEO_PROCESSING_ERROR_INVALID_INSTANCE] if instance is null or not a video processing instance.

[VIDEO_PROCESSING_ERROR_INVALID_PARAMETER] if window is null or *window is not null.

[VIDEO_PROCESSING_ERROR_OPERATION_NOT_PERMITTED] if creating surface failed, input surface is already created or video processing instance is running.

Available since API-level: 12