OH_VideoProcessing_InitializeEnvironment

Function OH_VideoProcessing_InitializeEnvironment 

pub unsafe extern "C" fn OH_VideoProcessing_InitializeEnvironment() -> VideoProcessing_ErrorCode
Available on crate features api-12 and video-processing only.
Initialize global environment for video processing.

This function is optional.

Typically, this function is called once when the host process is started to initialize the global environment for video processing, which can reduce the time of OH_VideoProcessing_Create.

To deinitialize global environment, call OH_VideoProcessing_DeinitializeEnvironment.

Returns

  • [VIDEO_PROCESSING_SUCCESS] if initialization is successful.

[VIDEO_PROCESSING_ERROR_INITIALIZE_FAILED] if initialization is failed.

You can check if the device GPU is working properly.

Available since API-level: 12