OH_VideoProcessing_SetParameter

Function OH_VideoProcessing_SetParameter 

pub unsafe extern "C" fn OH_VideoProcessing_SetParameter(
    videoProcessor: *mut OH_VideoProcessing,
    parameter: *const OH_AVFormat,
) -> VideoProcessing_ErrorCode
Available on crate features api-12 and video-processing only.
Set parameter for video processing.

Add parameter identified by the specified parameter key.

Arguments

  • videoProcessor - An video processing instance pointer.

  • parameter - The parameter for video processing.

Returns

  • [VIDEO_PROCESSING_SUCCESS] if setting parameter is successful.

[VIDEO_PROCESSING_ERROR_INVALID_INSTANCE] if instance is null or not an video processing instance.

[VIDEO_PROCESSING_ERROR_INVALID_PARAMETER] if the parameter is null.

[VIDEO_PROCESSING_ERROR_INVALID_VALUE] if some property of the parameter is invalid. For example, the parameter contains unsupported parameter key or value.

[VIDEO_PROCESSING_ERROR_NO_MEMORY] if memory allocation failed.

Available since API-level: 12