OH_ImageProcessing_Create

Function OH_ImageProcessing_Create 

pub unsafe extern "C" fn OH_ImageProcessing_Create(
    imageProcessor: *mut *mut OH_ImageProcessing,
    type_: i32,
) -> ImageProcessing_ErrorCode
Available on crate features api-13 and image-processing only.
Create an image processing instance.

Arguments

  • imageProcessor - Output parameter. The *imageProcessor points to a new image processing object. The *imageProcessor must be null before passed in.

  • type - Use IMAGE_PROCESSING_TYPE_XXX to specify the processing type. The processing type of the instance can not be changed.

Returns

  • [IMAGE_PROCESSING_SUCCESS] if creating an image processing successfully.

[IMAGE_PROCESSING_ERROR_UNSUPPORTED_PROCESSING] if the type is not supported. For example, if metadata generation is not supported by vendor, it returns unsupported processing.

[IMAGE_PROCESSING_ERROR_CREATE_FAILED] if failed to create an image processing.

[IMAGE_PROCESSING_ERROR_INVALID_INSTANCE] if instance is null or *instance is not null.

[IMAGE_PROCESSING_ERROR_INVALID_PARAMETER] if type is invalid.

Available since API-level: 13