pub unsafe extern "C" fn OH_VideoProcessingCallback_Destroy(
callback: *mut VideoProcessing_Callback,
) -> VideoProcessing_ErrorCodeAvailable on crate features
api-12 and video-processing only.Expand description
Destroy the callback object.
The callback object can be destroyed after it is registered to video processing instance.
Arguments
callback- The callback object pointer. It is recommended setting the callback pointer to null after the callback object is destroyed.
Returns
- [
VIDEO_PROCESSING_SUCCESS] if callback is successfully destroyed.
[VIDEO_PROCESSING_ERROR_INVALID_PARAMETER] if callback is null.
Available since API-level: 12