pub unsafe extern "C" fn OH_VideoProcessing_Destroy(
videoProcessor: *mut OH_VideoProcessing,
) -> VideoProcessing_ErrorCodeAvailable on crate features
api-12 and video-processing only.Expand description
Destroy the video processing instance.
Stop the instance before destroying it. see OH_VideoProcessing_Stop.
Arguments
videoProcessor- The video processing instance pointer to be destroyed. It is recommended setting the instance pointer to null after the instance is destroyed.
Returns
- [
VIDEO_PROCESSING_SUCCESS] if the instance is destroyed successfully .
[VIDEO_PROCESSING_ERROR_INVALID_INSTANCE] if instance is null or not a video processing instance.
[VIDEO_PROCESSING_ERROR_OPERATION_NOT_PERMITTED] if the instance is still running.
Available since API-level: 12