pub unsafe extern "C" fn OH_VideoProcessing_RenderOutputBuffer(
videoProcessor: *mut OH_VideoProcessing,
index: u32,
) -> VideoProcessing_ErrorCodeAvailable on crate features
api-12 and video-processing only.Expand description
Send the output buffer out.
If the callback function OH_VideoProcessingCallback_OnNewOutputBuffer is set, the buffer’s index is reported
to user by the callback function when an output buffer is ready.
Arguments
-
videoProcessor- A video processing instance pointer. -
index- The output buffer’s index.
Returns
- [
VIDEO_PROCESSING_SUCCESS] if the operation is successful.
[VIDEO_PROCESSING_ERROR_INVALID_INSTANCE] if instance is null or not a video processing instance.
[VIDEO_PROCESSING_ERROR_INVALID_PARAMETER] if index is invalid.
[VIDEO_PROCESSING_ERROR_OPERATION_NOT_PERMITTED] if callback [OH_VideoProcessing_OnNewOutputBuffer] is
not set or instance is stopped.
Available since API-level: 12